@@ -77,8 +77,8 @@ class CovidFields(BaseModel):
 
 class OutData(BaseModel):
     address: str
-    lat: Optional[Decimal]
-    long: Optional[Decimal]
+    lat: Optional[str]
+    long: Optional[str]
 
 
 class LabExtraFields(BaseModel):
@@ -113,6 +113,7 @@ class Source(str, Enum):
     site = "site"
     call_center = "call_center"
     delivery = "delivery"
+    mobile = "mobile"
 
 
 class PayType(str, Enum):
@@ -280,6 +281,8 @@ class DeliveryPreRecordRequest(BaseModel):
 class ClientPreRecordsRequest(BaseModel):
     client_uuid: Optional[str]
     phone: Optional[str]
+    d_to: Optional[datetime.date]
+    lname: Optional[str]
     limit: int = 10
     offset: int = 0
 
@@ -493,7 +496,6 @@ class PreRecordService:
         with_pagination: bool = False,
         timeout: int = 10,
     ) -> SDKResponse[Union[List[PreRecordResponse], PaginatedPreRecordResponse]]:
-        print(query.dict())
         resp: SDKResponse[PaginatedPreRecordResponse] = self._client.get(
             f"{self._url}rest/pre_record/",
             PaginatedPreRecordResponse,
